@@ -1,18 +1,19 @@
 package HTML::FormFu::Constraint::Repeatable::Any;
-use Moose;
 
-extends 'HTML::FormFu::Constraint';
+use strict;
+use base 'HTML::FormFu::Constraint';
+use Class::C3;
 
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
-after BUILD => sub {
-    my $self = shift;
+sub new {
+    my $self = shift->next::method(@_);
 
     $self->only_on_reps([1]);
 
-    return;
-};
+    return $self;
+}
 
 sub process {
     my ( $self, $params ) = @_;
@@ -26,11 +27,11 @@ sub process {
     my $repeatable = $field->get_parent({ type => 'Repeatable' });
     my $pass;
 
-    my $original_name = $field->original_name || '';
+    my $original_name = $field->original_name;
 
     my @fields =
         grep { $_->get_parent({ type => 'Repeatable' }) == $repeatable }
-        grep { ( $_->original_name || '' ) eq $original_name }
+        grep { $_->original_name eq $original_name }
             @{ $repeatable->get_fields };
 
     my $increment_field_names = $repeatable->increment_field_names;
@@ -100,8 +101,6 @@ sub constrain_value {
     return defined $value && length $value;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
