@@ -20,9 +20,10 @@ use HTML::FormFu::ObjectUtil qw(
     form
     stash
     parent
+    get_parent
 );
 use HTML::FormFu::Util qw( require_class xml_escape );
-use Scalar::Util qw( refaddr weaken );
+use Scalar::Util qw( refaddr reftype weaken );
 use Storable qw( dclone );
 use Carp qw( croak );
 
@@ -58,10 +59,14 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( config_callback ));
 
 sub new {
     my $class = shift;
-
     my %attrs;
-    eval { %attrs = %{ $_[0] } if @_ };
-    croak "attributes argument must be a hashref" if $@;
+
+    if (@_) {
+        croak "attributes argument must be a hashref"
+            if reftype( $_[0] ) ne 'HASH';
+        
+        %attrs = %{ $_[0] };
+    }
 
     my $self = bless {}, $class;
 
@@ -464,13 +469,22 @@ See L<HTML::FormFu::Element::_Field/prepare_attrs> for details.
 
 Return Value: $string
 
-=head2 INTROSPECTION
+=head1 INTROSPECTION
 
 =head2 parent
 
 Returns the L<block element|HTML::FormFu::Element> or L<form|HTML::FormFu> 
 object that this element is attached to.
 
+=head2 get_parent
+
+Arguments: \%options
+
+    my $repeatable = $field->get_parent({ type => 'Repeatable' });
+
+Traverses the parent hierarchy, returning the first parent that matches the
+supplied options.
+
 =head2 form
 
 Returns the L<HTML::FormFu> object that the constraint's field is attached 
