@@ -6,13 +6,14 @@ use Class::C3;
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
-__PACKAGE__->mk_output_accessors( qw( default ) );
+__PACKAGE__->mk_output_accessors(qw( default ));
 
 sub new {
     my $self = shift->next::method(@_);
 
-    $self->field_type   ( 'checkbox' );
-    $self->reverse_multi( 1 );
+    $self->field_type('checkbox');
+    $self->reverse_multi(1);
+    $self->value(1);
 
     return $self;
 }
@@ -32,7 +33,7 @@ sub prepare_attrs {
     my $submitted = $form->submitted;
     my $default   = $self->default;
     my $original  = $self->value;
-    
+
     my $value
         = defined $self->name
         ? $self->get_nested_hash_value( $form->input, $self->nested_name )
@@ -81,9 +82,13 @@ Checkbox form field.
 
 =head1 METHODS
 
+=head2 value
+
+Default Value: 1
+
 =head2 default_empty_value
 
-Inherited. See L<HTML::FormFu/default_empty_value> for details.
+Inherited. See L<HTML::FormFu::Element::_Field/default_empty_value> for details.
 
 =head2 reverse_multi
 
